summaryrefslogtreecommitdiff
path: root/regnodes.h
diff options
context:
space:
mode:
authorYves Orton <demerphq@gmail.com>2022-07-30 18:43:01 +0200
committerYves Orton <demerphq@gmail.com>2022-08-03 11:07:09 +0200
commit609756f2528a92f7d426129a05d53878dcf547d5 (patch)
treeef31b72b3b2f665ef2bedbaabf633a5be19977be /regnodes.h
parente794fa41fb8d8ec5b090155365d648e1d3e9daf5 (diff)
downloadperl-609756f2528a92f7d426129a05d53878dcf547d5.tar.gz
regex engine - Rename reg_off_by_arg to PL_reg_off_by_arg
This is in preparation for a future patch, so we can access PL_reg_off_by_arg() from an inline function in regexec.c
Diffstat (limited to 'regnodes.h')
-rw-r--r--regnodes.h13
1 files changed, 6 insertions, 7 deletions
diff --git a/regnodes.h b/regnodes.h
index 8d29900e0c..45cbd071b6 100644
--- a/regnodes.h
+++ b/regnodes.h
@@ -1857,11 +1857,12 @@ EXTCONST U8 PL_regarglen[] = {
#endif /* DOINIT */
-#ifdef REG_COMP_C
+/* PL_reg_off_by_arg[] - Which argument holds the offset to the next node */
-/* reg_off_by_arg[] - Which argument holds the offset to the next node */
-
-static const char reg_off_by_arg[] = {
+#ifndef DOINIT
+EXTCONST U8 PL_reg_off_by_arg[];
+#else
+EXTCONST U8 PL_reg_off_by_arg[] = {
0, /* END */
0, /* SUCCEED */
0, /* SBOL */
@@ -1975,9 +1976,7 @@ static const char reg_off_by_arg[] = {
0, /* PSEUDO */
0, /* REGEX_SET */
};
-
-#endif /* REG_COMP_C */
-
+#endif
/* reg_name[] - Opcode/state names in string form, for debugging */